#
# spec file for package libregf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libregf1
Name:           libregf
Version:        20231203
Release:        1.1
Summary:        Library to access Windows REGF-type Registry files
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libregf
Source:         https://github.com/libyal/libregf/releases/download/%version/libregf-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libregf/releases/download/%version/libregf-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source11:       Windows_NT_Registry_File_REGF_format.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfcache) >= 20230115
BuildRequires:  pkgconfig(libfdata) >= 20230319
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libfwnt) >= 20231124
BuildRequires:  pkgconfig(libfwsi) >= 20231130
BuildRequires:  pkgconfig(libuna) >= 20230710
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

%package -n %lname
Summary:        Library to access Windows REGF-type Registry files
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

%package tools
Summary:        Utilities to inspect Windows REGF-type Registry files
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Several tools for inspecting Windows REGF-type Registry files.
Typically used for computer forensics.

%package devel
Summary:        Development files for libregf, a Windows REGF-type Registry file parser
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %{version}
Requires:       libbfio-devel

%description devel
libregf is a library to access Windows Registry files of the REGF
type (a non-text representation).

This subpackage contains libraries and header files for developing
applications that want to make use of %{name}.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%{_libdir}/libregf.so.*

%files -n %name-tools
%{_bindir}/regf*
%{_mandir}/man1/regf*.1*

%files -n %name-devel
%doc Windows_NT_Registry_File*.pdf
%{_includedir}/libregf.h
%{_includedir}/libregf/
%{_libdir}/libregf.so
%{_libdir}/pkgconfig/libregf.pc
%{_mandir}/man3/libregf.3*

%files %python_files
%license COPYING*
%{python_sitearch}/pyregf.so

%changelog
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231203
  * Build system changes only
* Sun Oct 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231029
  * Rename function ``libregf_hive_bins_list_read`` to
    ``libregf_hive_bins_list_read_file_io_handle``
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Thu Mar 23 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230319
  * No changelog
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Oct 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221026
  * No changelog was provided
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile, libfwsi
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Tue Feb  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220131
  * No changelog was provided
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables python2 on Leap 15.)
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210809
  * No changelog was provided
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210615
  * No changelog was provided
- Drop python2 module build
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210504 (ee938acd)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 31 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20201007
  * Changes to handle additional corruption scenarios
- Add COPYING* to %%license line
- remove  BuildRequires: pkg-config
* Sat Dec 26 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20200805
  * Changes to handle multi-string corruption scenario
  * Worked on Python Bindings
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to disable python2 build (bcond_without python2):
  Tumbleweed already declares this, as python2 is EOL.
* Mon Apr  6 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20191221
  * Worked on REG_MULTI_SZ support
  * Added key path to regfexport output
  * Added key path option to export tool
  * Worked on thread lock support and tests
  * Changes for local usage of libregf
- add python3 subpackage
* Wed Apr 17 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20190303
  * Applied updates and changes for class name
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to 20170130
- use these packages from factory to see if they are stable yet:
  * libfcache
  * libfdata
  * libfwnt
  * libfwsi
- change RPM group for python binding to development/languages/python
* Mon Feb  1 2016 Greg.Freemyer@gmail.com
- update to 20160107
  * worked on Python 3 support
  * worked on format support
  * changed libregf_value_get_value_type to require a 32-bit value type
  * worked for transaction log support
  * worked on Python bindings
  * worked on handling corrupt integer values
  * enlarged pyregf error string buffer
  * worked on setup.py
* Thu Aug 13 2015 Greg.Freemyer@gmail.com
- update to 20150704
  * worked on handling corrupt hive bins
  * worked on empty hive bins data corruption scenario handling
  * worked on Python-bindings
  * Bug fixes
* Fri May  8 2015 Greg.Freemyer@gmail.com
- update to 20150315
  * bug fix in _get_sub_key_by_path for single character sub key paths
* Wed Jan 14 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * removed libregf_file_get_version
- update Source and URL fields to use the new github site
- use more libyal packages from OBS
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 20140905
  * updated libfwsi version check
  * bug fix in Python-bindings
  * code clean
- update Source field to fullpath - delete DL_URL field
- use libcerror from external package
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pyregf = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140803
  * bug fix in Python-bindings
  * worked on Python bindings
  * worked on regfmount
  - moved values to sub directory to prevent value and key name clashes
  - added class name support
  - other tasks
  * updated dependencies
  * fix for dealing with size mismatch between value and block list size
  * improved string size corruption handling
  * worked on setup.py
  * bug fix for call to libfdata_tree_node_set_sub_nodes_data_range
  * 2014 update
  * worked on Dokan support for regfmount
* Sat Nov 23 2013 Greg.Freemyer@gmail.com
- update to v0~20131013
- clean up buildrequires
- use libyal packages from factory if feasible
* Wed Oct  2 2013 Greg.Freemyer@gmail.com
- update to v0~20130922
  * removed hardcoded codepages from value functions
  * worked on automated tests
  * updated dependencies
* Tue Aug 27 2013 Greg.Freemyer@gmail.com
- update to v0~20130821
  * fix in pyregf value data as integer function for bounds check being too strict
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- update to v0~20130716
  * updated dependencies
  * worked on tests
  * bug fix for large values
  * added support for REG_LINK as a string
  * fixed multiple open issues
  * pyregf: fix for retrieving default value by name
  * worked on tests
  * changes for strings values with trailing data
  * small update for 64-bit build
  * Textual changes
  * updates and bug fixes in pyregf
  * fixed codepage 1255 restriction
  * fixed codepage 949 and 950 restriction
  * changes for libfdata update
  * removed item flags
- changed to gz compression to simplyfy download/convert
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- organize BuildRequires to better comment why they are commented out
- ran spec-cleaner
* Wed Apr  3 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; less greedy fileslists; remove unused %%py_requires;
  do not bloat shlib package with documentation
- Enable FUSE support
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130319) for build.opensuse.org
